@@ -36,7 +36,7 @@ def main():
             post='80'
         else:
             post=args.post
-        Version='1.1.7'
+        Version='1.2.6'
         console = Console()
         table = Table(title="[red]M x P i[/red]",style="bold")
         table.add_column("Version:"+Version, style="cyan", no_wrap=True,justify="center")
@@ -67,15 +67,14 @@ def main():
             #console.print("",style=" red")
             #console.print("(Ctrl+C或者关闭终端即可关闭MxPi)",style="red")
             cmds('cd '+os.path.dirname(mxpi.__file__)+' & daphne mxpi.app.asgi:django_application -b '+ip+" -p "+post+" -v 0")
+            #cmds('cd '+os.path.dirname(mxpi.__file__)+' & daphne mxpi.app.asgi:django_application -b '+ip+" -p "+post)
         else:
             #console.print("MxPi启动成功,打开:http://"+ip+':'+post ,style="bold #0ba248")
             #console.print("(Ctrl+C或者关闭终端即可关闭MxPi)",style="bold red")
             cmds('cd '+os.path.dirname(mxpi.__file__)+' & sudo daphne mxpi.app.asgi:django_application -b '+ip+" -p "+post+" -v 0")
+            #cmds('cd '+os.path.dirname(mxpi.__file__)+' & sudo daphne mxpi.app.asgi:django_application -b '+ip+" -p "+post)
     else:
         if(platform.system()=='Windows'):
             cmds('python '+os.path.abspath(os.path.dirname(mxpi.__file__))+'/file/test.py')
         else:
-            cmds('sudo python3 '+os.path.abspath(os.path.dirname(mxpi.__file__))+'/file/test.py')
-
-
-main()
\ No newline at end of file
+            cmds('sudo python3 '+os.path.abspath(os.path.dirname(mxpi.__file__))+'/file/test.py')
\ No newline at end of file
