@@ -52,6 +52,7 @@ class remote_desktop_Thread (threading.Thread):
                 # Convert to PIL/Pillow Image
                 return Image.frombytes('RGB', sct_img.size, sct_img.bgra, 'raw', 'BGRX')
                 #return img
+                
 class RunThread (threading.Thread):
     def __init__(self, chat):
         threading.Thread.__init__(self)
@@ -192,12 +193,13 @@ class Pip_install_Thread (threading.Thread):
             self.chat.send(json.dumps({'msg':'pip_stop','data':'结束'}))
 
 class install_ku_Thread (threading.Thread):
-    def __init__(self, chat,name,yuan):
+    def __init__(self, chat,name,yuan,s):
         threading.Thread.__init__(self)
         self.chat = chat
         self.read_stop=False
         self.name=name
         self.yuan=yuan
+        self.s=s
     def run(self):
         global p
         url=os.path.dirname(mxpi.__file__)
@@ -205,9 +207,12 @@ class install_ku_Thread (threading.Thread):
         if(platform.system()=='Windows'):
             shell_cmd ='pip install '+self.name+' -i '+ self.yuan
         elif (platform.uname().system=='Linux' and platform.uname().machine=='aarch64'):
-            shell_cmd ='sudo sh '+url+'/install_ku/'+self.name+'.sh'
+            if self.s=='yuzhi':
+                shell_cmd ='sudo sh '+url+'/install_ku/'+self.name+'.sh'
+            else:
+                shell_cmd ='sudo pip3 install '+self.name+' -i '+ self.yuan
         else:
-            shell_cmd ='pip install '+self.name+' -i '+ self.yuan
+            shell_cmd ='sudo pip3 install '+self.name+' -i '+ self.yuan
         self.chat.send(json.dumps({'msg':'pip_msg','data':shell_cmd}))
         print(shell_cmd)
         cmd = shlex.split(shell_cmd)
@@ -361,7 +366,8 @@ class ChatConsumer(WebsocketConsumer):
 
             ]
             yuan_id=data['pipyuan']
-            self.ku=install_ku_Thread(self,data['name'],yuan[int(yuan_id)])
+            s=data['s']
+            self.ku=install_ku_Thread(self,data['name'],yuan[int(yuan_id)],s)
             self.ku.start()
             self.send(json.dumps({'msg':'pip_msg','data':'开始安装'}))
         
