@@ -24,6 +24,9 @@ import platform
 def home(request):
     return render(request,'index.html')
 
+def vnc(request):
+    return render(request,'vnc.html')
+
 def upfile(request):
     code = request.POST.get('code')
     f=open(os.path.dirname(mxpi.__file__)+'/file/test.py','w',encoding='utf-8')
