@@ -1055,6 +1055,7 @@ resizeOpacity: 1,
   });
   $("#DKmodel").on("click", function(event){
     var dk=chatSocket.send(JSON.stringify({'msg':'remote_desktop'}))
+    
     $("#DK_content").PopupWindow("open");
   });
 }
@@ -1091,7 +1092,7 @@ function pipinstall(){
   list_num_pip=0
   list_nums_pip=0
   var pip_install_name=document.getElementById('pip_install_name').value;
-  install_ku(pip_install_name)
+  install_ku(pip_install_name,'pip')
 }
 
 function connect_server(){
@@ -1560,6 +1561,8 @@ function pip_list(){
     {id:7, name:"SoundFile",  col:"音频文件操作", arr:'win/Liunx/rpi',cheese:re('SoundFile')},
     {id:8, name:"librosa",  col:"用于音乐和音频分析的python包", arr:'win/Liunx/rpi',cheese:re('librosa')},
     {id:9, name:"hcsr04sensor",  col:"超声波传感器的依赖库", arr:'rpi',cheese:re('hcsr04sensor')},
+    {id:10, name:"pyqtgraph",  col:"PyQt5可视化库", arr:'win/Liunx/rpi',cheese:re('pyqtgraph')},
+    {id:11, name:"onnxruntime",  col:"目标检测的依赖库", arr:'win/Liunx/rpi',cheese:re('onnxruntime')},
   ]);
 }
 
@@ -1591,6 +1594,12 @@ function c_list(){
     {id:16, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
     {id:17, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
     {id:18, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
+    {id:19, name:"行空板-1",  col:"行空板打开摄像头",cheese:ce('19')},
+    {id:20, name:"行空板-2",  col:"行空板进行色块识别",cheese:ce('20')},
+    {id:21, name:"行空板-3",  col:"行空板进行目标检测",cheese:ce('21')},
+    {id:22, name:"行空板-4",  col:"行空板GET网络天气进行显示",cheese:ce('22')},
+    {id:23, name:"行空板-5",  col:"行空板PyQt交互案例",cheese:ce('23')},
+    {id:24, name:"行空板-6",  col:"行空板PyQt试试绘制加速度值，需要安装pyqtgraph",cheese:ce('24')},
   ]);
 }
 var model_lists
@@ -1673,13 +1682,13 @@ function get_c(name){
 }
 
 function re(name){
-  return "<div style='display:flex;justify-content: space-around;'><div onclick='install_ku(\""+name+"\")'><i class='fa fa-arrow-circle-down' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div></div>"
+  return "<div style='display:flex;justify-content: space-around;'><div onclick='install_ku(\""+name+"\",\"yuzhi\")'><i class='fa fa-arrow-circle-down' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div></div>"
 }
-function install_ku(name){
+function install_ku(name,s){
   console.log(name)
   yuan=document.getElementById("pip-yuan").selectedIndex;
   addpip('开始安装 '+name+' ,请保持网络畅通。')
-  chatSocket.send(JSON.stringify({'msg':'install_ku','name':name,'pipyuan':yuan}))
+  chatSocket.send(JSON.stringify({'msg':'install_ku','name':name,'pipyuan':yuan,'s':s}))
 }
 
 var rec=false
