@@ -201,6 +201,21 @@ Blockly.Blocks.python_opencv_imread= {
     }
   };
 
+  Blockly.Blocks.python_opencv_opencam_rtsp= {
+    init: function() {
+    this.appendDummyInput()
+        .appendField("打开视频流");
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('OpenCV_blocks');
+    this.setTooltip("opencv打开视频流");
+    this.setHelpUrl("");
+    }
+  };
+
   Blockly.Blocks.python_opencv_cap_setHW= {
     init: function() {
     this.appendValueInput("NAME")
